imbalanced_ensemble.metrics — imbalanced-ensemble 0.1.0 documentation

# `imbalanced_ensemble.metrics`

This is the full API documentation of the imbalanced_ensemble.metrics module.

- Classification Metrics
  - sensitivity_specificity_support
  - sensitivity_score
  - specificity_score
  - geometric_mean_score
    - Examples using `imbalanced_ensemble.metrics.geometric_mean_score`
  - make_index_balanced_accuracy
    - Examples using `imbalanced_ensemble.metrics.make_index_balanced_accuracy`
  - classification_report_imbalanced
    - Examples using `imbalanced_ensemble.metrics.classification_report_imbalanced`
  - macro_averaged_mean_absolute_error
- Pairwise Metrics
  - ValueDifferenceMetric